@@ -26,6 +26,17 @@
 #include "src/compiled.h"
 #include "floattypes.h"
 
+
+// HACK HACK HACK: workaround an issue where atexit() calls are inserted by
+// the compiler into C++ code compiled with coverage tracking (via the
+// --coverage compiler and linker option); this then causes a linker error
+// when trying to load float.so on Linux with glibc, where atexit() is not
+// exported by libc.so.
+int atexit(void (*func)(void))
+{
+  return 0;
+}
+
 Obj FLOAT_INFINITY_STRING, /* pretty strings */
   FLOAT_NINFINITY_STRING,
   FLOAT_EMPTYSET_STRING,
@@ -82,6 +93,10 @@ mpz_ptr mpz_MPZ (Obj obj) {
 
 Obj INT_mpz(mpz_ptr z)
 {
+#if GAP_KERNEL_MAJOR_VERSION >= 7
+    // added in GAP 4.11
+    return MakeObjInt((const UInt *)z->_mp_d, z->_mp_size);
+#else
   if (mpz_sgn(z) == 0) {
     return INTOBJ_INT(0);
   }
@@ -97,6 +112,7 @@ Obj INT_mpz(mpz_ptr z)
   res = GMP_REDUCE(res);
 
   return res;
+#endif
 }
 
 #if 0
